@@ -1,4 +1,4 @@
-package Pcore::API::Moz v0.8.0;
+package Pcore::API::Moz v0.8.1;
 
 use Pcore -dist, -class, -result;
 use Pcore::API::Moz::Account;
@@ -25,9 +25,11 @@ sub BUILD ( $self, $args ) {
 
 sub add_accounts ( $self, $accounts ) {
     for my $id ( keys $accounts->%* ) {
-        next if exists $self->{_accs_ids}->{$id};
+        my $acc_id = "$id-$accounts->{$id}";
 
-        $self->{_accs_ids}->{$id} = undef;
+        next if exists $self->{_accs_ids}->{$acc_id};
+
+        $self->{_accs_ids}->{$acc_id} = undef;
 
         unshift $self->{valid_accounts}->@*, Pcore::API::Moz::Account->new( { moz => $self, id => $id, key => $accounts->{$id} } );
 
